@@ -56,8 +56,11 @@ brain imaging features, whose experiments often measure their correlation with t
        47 (2), 106–14.
 .. [3] Vasilyev, D. M., *et al.* (2014). `An algorithm for score aggregation over causal biological networks based on
        random walk sampling <https://doi.org/10.1186/1756-0500-7-516>`_. BMC Research Notes, 7, 516.
+
 """
 
+from __future__ import annotations
+
 import logging
 import random
 from collections import defaultdict
@@ -66,14 +69,13 @@ from typing import Any, Callable, Hashable, Iterable, List, Mapping, Optional, S
 
 import numpy as np
 from scipy import stats
-from tqdm import tqdm
+from tqdm import tqdm, trange
 
 from pybel import BELGraph
 from pybel.constants import BIOPROCESS, CAUSAL_DECREASE_RELATIONS, CAUSAL_INCREASE_RELATIONS, RELATION
 from pybel.dsl import BaseEntity
-from pybel.struct.filters.node_selection import get_nodes_by_function
+from pybel.struct.filters import get_nodes_by_function
 from pybel.struct.grouping import get_subgraphs_by_annotation
-from ..constants import WEIGHT
 from ..generation import generate_bioprocess_mechanisms, generate_mechanism
 
 __all__ = [
@@ -89,7 +91,7 @@ __all__ = [
     'Runner',
 ]
 
-log = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 #: The key for the heat diffusion score in the node's data dictionary
 SCORE = 'score'
@@ -107,15 +109,18 @@ RESULT_LABELS = [
     'subgraph_size',
 ]
 
+H = TypeVar('H', bound=Hashable)
+SubgraphScores = Mapping[H, Tuple[float, float, float, float, int, int]]
+
 
 def calculate_average_scores_on_graph(
-        graph: BELGraph,
-        key: Optional[str] = None,
-        tag: Optional[str] = None,
-        default_score: Optional[float] = None,
-        runs: Optional[int] = None,
-        use_tqdm: bool = False,
-):
+    graph: BELGraph,
+    key: Optional[str] = None,
+    tag: Optional[str] = None,
+    default_score: Optional[float] = None,
+    runs: Optional[int] = None,
+    use_tqdm: bool = False,
+) -> SubgraphScores:
     """Calculate the scores over all biological processes in the sub-graph.
 
     As an implementation, it simply computes the sub-graphs then calls :func:`calculate_average_scores_on_subgraphs` as
@@ -138,32 +143,27 @@ def calculate_average_scores_on_graph(
     >>> graph = ...  # load graph and data
     >>> scores = calculate_average_scores_on_graph(graph)
     >>> pd.DataFrame.from_items(scores.items(), orient='index', columns=RESULT_LABELS)
-
     """
     subgraphs = generate_bioprocess_mechanisms(graph, key=key)
-    scores = calculate_average_scores_on_subgraphs(
+    return calculate_average_scores_on_subgraphs(
         subgraphs,
         key=key,
         tag=tag,
         default_score=default_score,
         runs=runs,
-        use_tqdm=use_tqdm
+        use_tqdm=use_tqdm,
     )
-    return scores
-
-
-H = TypeVar('H', bound=Hashable)
 
 
 def calculate_average_scores_on_subgraphs(
-        subgraphs: Mapping[H, BELGraph],
-        key: Optional[str] = None,
-        tag: Optional[str] = None,
-        default_score: Optional[float] = None,
-        runs: Optional[int] = None,
-        use_tqdm: bool = False,
-        tqdm_kwargs: Optional[Mapping[str, Any]] = None,
-) -> Mapping[H, Tuple[float, float, float, float, int, int]]:
+    subgraphs: Mapping[H, BELGraph],
+    key: Optional[str] = None,
+    tag: Optional[str] = None,
+    default_score: Optional[float] = None,
+    runs: Optional[int] = None,
+    use_tqdm: bool = False,
+    tqdm_kwargs: Optional[Mapping[str, Any]] = None,
+) -> SubgraphScores:
     """Calculate the scores over precomputed candidate mechanisms.
 
     :param subgraphs: A dictionary of keys to their corresponding subgraphs
@@ -188,7 +188,7 @@ def calculate_average_scores_on_subgraphs(
     """
     results = {}
 
-    log.info('calculating results for %d candidate mechanisms using %d permutations', len(subgraphs), runs)
+    logger.info('calculating results for %d candidate mechanisms using %d permutations', len(subgraphs), runs)
 
     it = subgraphs.items()
 
@@ -237,14 +237,14 @@ def calculate_average_scores_on_subgraphs(
 
 
 def workflow(
-        graph: BELGraph,
-        node: BaseEntity,
-        key: Optional[str] = None,
-        tag: Optional[str] = None,
-        default_score: Optional[float] = None,
-        runs: Optional[int] = None,
-        minimum_nodes: int = 1,
-) -> List['Runner']:
+    graph: BELGraph,
+    node: BaseEntity,
+    key: Optional[str] = None,
+    tag: Optional[str] = None,
+    default_score: Optional[float] = None,
+    runs: Optional[int] = None,
+    minimum_nodes: int = 1,
+) -> List[Runner]:
     """Generate candidate mechanisms and run the heat diffusion workflow.
 
     :param graph: A BEL graph
@@ -262,18 +262,25 @@ def workflow(
     if subgraph.number_of_nodes() <= minimum_nodes:
         return []
 
-    runners = multirun(subgraph, node, key=key, tag=tag, default_score=default_score, runs=runs)
-    return list(runners)
+    return list(multirun(
+        subgraph,
+        node,
+        key=key,
+        tag=tag,
+        default_score=default_score,
+        runs=runs,
+    ))
 
 
-def multirun(graph: BELGraph,
-             node: BaseEntity,
-             key: Optional[str] = None,
-             tag: Optional[str] = None,
-             default_score: Optional[float] = None,
-             runs: Optional[int] = None,
-             use_tqdm: bool = False,
-             ) -> Iterable['Runner']:
+def multirun(
+    graph: BELGraph,
+    node: BaseEntity,
+    key: Optional[str] = None,
+    tag: Optional[str] = None,
+    default_score: Optional[float] = None,
+    runs: Optional[int] = None,
+    use_tqdm: bool = False,
+) -> Iterable[Runner]:
     """Run the heat diffusion workflow multiple times, each time yielding a :class:`Runner` object upon completion.
 
     :param graph: A BEL graph
@@ -289,30 +296,26 @@ def multirun(graph: BELGraph,
     if runs is None:
         runs = 100
 
-    it = range(runs)
-
-    if use_tqdm:
-        it = tqdm(it, total=runs)
-
-    for i in it:
+    for i in (trange(runs) if use_tqdm else range(runs)):
         try:
             runner = Runner(graph, node, key=key, tag=tag, default_score=default_score)
             runner.run()
             yield runner
         except Exception:
-            log.debug('Run %s failed for %s', i, node)
+            logger.debug('Run %s failed for %s', i, node)
 
 
 class Runner:
     """This class houses the data related to a single run of the heat diffusion workflow."""
 
-    def __init__(self,
-                 graph: BELGraph,
-                 target_node: BaseEntity,
-                 key: Optional[str] = None,
-                 tag: Optional[str] = None,
-                 default_score: Optional[float] = None,
-                 ) -> None:
+    def __init__(
+        self,
+        graph: BELGraph,
+        target_node: BaseEntity,
+        key: Optional[str] = None,
+        tag: Optional[str] = None,
+        default_score: Optional[float] = None,
+    ) -> None:
         """Initialize the heat diffusion runner class.
 
         :param graph: A BEL graph
@@ -324,14 +327,14 @@ class Runner:
         """
         self.graph: BELGraph = graph.copy()
         self.target_node = target_node
-        self.key = key or WEIGHT
+        self.key = key or 'weight'
         self.default_score = default_score or DEFAULT_SCORE
         self.tag = tag or SCORE
 
         for node, data in self.graph.nodes(data=True):
             if not self.graph.predecessors(node):
                 self.graph.nodes[node][self.tag] = data.get(self.key, 0)
-                log.log(5, 'initializing %s with %s', target_node, self.graph.nodes[node][self.tag])
+                logger.log(5, 'initializing %s with %s', target_node, self.graph.nodes[node][self.tag])
 
     def iter_leaves(self) -> Iterable[BaseEntity]:
         """Return an iterable over all nodes that are leaves.
@@ -367,7 +370,9 @@ class Runner:
                 yield node
 
     def get_random_edge(self):
-        """This function should be run when there are no leaves, but there are still unscored nodes. It will introduce
+        """Get a random edge adjacent to an unscored node based on the in/out ratio.
+
+        This function should be run when there are no leaves, but there are still unscored nodes. It will introduce
         a probabilistic element to the algorithm, where some edges are disregarded randomly to eventually get a score
         for the network. This means that the score can be averaged over many runs for a given graph, and a better
         data structure will have to be later developed that doesn't destroy the graph (instead, annotates which edges
@@ -379,7 +384,6 @@ class Runner:
            4. pick randomly which edge
 
         :return: A random in-edge to the lowest in/out degree ratio node. This is a 3-tuple of (node, node, key)
-        :rtype: tuple
         """
         nodes = [
             (n, self.in_out_ratio(n))
@@ -388,20 +392,20 @@ class Runner:
         ]
 
         node, deg = min(nodes, key=itemgetter(1))
-        log.log(5, 'checking %s (in/out ratio: %.3f)', node, deg)
+        logger.log(5, 'checking %s (in/out ratio: %.3f)', node, deg)
 
         possible_edges = self.graph.in_edges(node, keys=True)
-        log.log(5, 'possible edges: %s', possible_edges)
+        logger.log(5, 'possible edges: %s', possible_edges)
 
         edge_to_remove = random.choice(possible_edges)
-        log.log(5, 'chose: %s', edge_to_remove)
+        logger.log(5, 'chose: %s', edge_to_remove)
 
         return edge_to_remove
 
     def remove_random_edge(self):
         """Remove a random in-edge from the node with the lowest in/out degree ratio."""
         u, v, k = self.get_random_edge()
-        log.log(5, 'removing %s, %s (%s)', u, v, k)
+        logger.log(5, 'removing %s, %s (%s)', u, v, k)
         self.graph.remove_edge(u, v, k)
 
     def remove_random_edge_until_has_leaves(self) -> None:
@@ -420,17 +424,19 @@ class Runner:
         leaves = set(self.iter_leaves())
 
         if not leaves:
-            log.warning('no leaves.')
+            logger.warning('no leaves.')
             return set()
 
         for leaf in leaves:
             self.graph.nodes[leaf][self.tag] = self.calculate_score(leaf)
-            log.log(5, 'chomping %s', leaf)
+            logger.log(5, 'chomping %s', leaf)
 
         return leaves
 
     def run(self) -> None:
-        """Calculate scores for all leaves until there are none, removes edges until there are, and repeats until
+        """Calculate scores for all leaves.
+
+        Calculate scores for all leaves until there are none, removes edges until there are, and repeats until
         all nodes have been scored.
         """
         while not self.done_chomping():
@@ -438,7 +444,9 @@ class Runner:
             self.score_leaves()
 
     def run_with_graph_transformation(self) -> Iterable[BELGraph]:
-        """Calculate scores for all leaves until there are none, removes edges until there are, and repeats until
+        """Calculate scores for all leaves while yielding the graph at each step.
+
+        Continues until there are none, removes edges until there are, and repeats until
         all nodes have been scored. Also, yields the current graph at every step so you can make a cool animation
         of how the graph changes throughout the course of the algorithm
 
@@ -453,11 +461,10 @@ class Runner:
             yield self.get_remaining_graph()
 
     def done_chomping(self) -> bool:
-        """Determines if the algorithm is complete by checking if the target node of this analysis has been scored
-        yet. Because the algorithm removes edges when it gets stuck until it is un-stuck, it is always guaranteed to
-        finish.
+        """Determine if the algorithm is complete.
 
-        :return: Is the algorithm done running?
+        Checking if the target node of this analysis has been scored yet. Because the algorithm removes edges when it
+        gets stuck until it is un-stuck, it is always guaranteed to finish.
         """
         return self.tag in self.graph.nodes[self.target_node]
 
@@ -488,7 +495,9 @@ class Runner:
         return score
 
     def get_remaining_graph(self) -> BELGraph:
-        """Allows for introspection on the algorithm at a given point by returning the sub-graph induced
+        """Get the graph induced over unscored nodes.
+
+        Allows for introspection on the algorithm at a given point by returning the sub-graph induced
         by all unscored nodes
 
         :return: The remaining un-scored BEL graph
@@ -496,14 +505,15 @@ class Runner:
         return self.graph.subgraph(self.unscored_nodes_iter())
 
 
-def workflow_aggregate(graph: BELGraph,
-                       node: BaseEntity,
-                       key: Optional[str] = None,
-                       tag: Optional[str] = None,
-                       default_score: Optional[float] = None,
-                       runs: Optional[int] = None,
-                       aggregator: Optional[Callable[[Iterable[float]], float]] = None,
-                       ) -> Optional[float]:
+def workflow_aggregate(
+    graph: BELGraph,
+    node: BaseEntity,
+    key: Optional[str] = None,
+    tag: Optional[str] = None,
+    default_score: Optional[float] = None,
+    runs: Optional[int] = None,
+    aggregator: Optional[Callable[[Iterable[float]], float]] = None,
+) -> Optional[float]:
     """Get the average score over multiple runs.
 
     This function is very simple, and can be copied to do more interesting statistics over the :class:`Runner`
@@ -524,7 +534,7 @@ def workflow_aggregate(graph: BELGraph,
     scores = [runner.get_final_score() for runner in runners]
 
     if not scores:
-        log.warning('Unable to run the heat diffusion workflow for %s', node)
+        logger.warning('Unable to run the heat diffusion workflow for %s', node)
         return
 
     if aggregator is None:
@@ -539,7 +549,7 @@ def workflow_all(graph: BELGraph,
                  default_score: Optional[float] = None,
                  runs: Optional[int] = None,
                  ) -> Mapping[BaseEntity, List[Runner]]:
-    """Run the heat diffusion workflow and get runners for every possible candidate mechanism
+    """Run the heat diffusion workflow and get runners for every possible candidate mechanism.
 
     1. Get all biological processes
     2. Get candidate mechanism induced two level back from each biological process
@@ -562,13 +572,14 @@ def workflow_all(graph: BELGraph,
     return results
 
 
-def workflow_all_aggregate(graph: BELGraph,
-                           key: Optional[str] = None,
-                           tag: Optional[str] = None,
-                           default_score: Optional[float] = None,
-                           runs: Optional[int] = None,
-                           aggregator: Optional[Callable[[Iterable[float]], float]] = None,
-                           ):
+def workflow_all_aggregate(
+    graph: BELGraph,
+    key: Optional[str] = None,
+    tag: Optional[str] = None,
+    default_score: Optional[float] = None,
+    runs: Optional[int] = None,
+    aggregator: Optional[Callable[[Iterable[float]], float]] = None,
+):
     """Run the heat diffusion workflow to get average score for every possible candidate mechanism.
 
     1. Get all biological processes
@@ -604,23 +615,24 @@ def workflow_all_aggregate(graph: BELGraph,
                 aggregator=aggregator
             )
         except Exception:
-            log.exception('could not run on %', bioprocess_node)
+            logger.exception('could not run on %', bioprocess_node)
 
     return results
 
 
 # TODO reinvestigate statistical bootstrapping/resampling/distribution normalization
 def calculate_average_score_by_annotation(
-        graph: BELGraph,
-        annotation: str,
-        key: Optional[str] = None,
-        runs: Optional[int] = None,
-        use_tqdm: bool = False,
+    graph: BELGraph,
+    annotation: str,
+    key: Optional[str] = None,
+    runs: Optional[int] = None,
+    use_tqdm: bool = False,
 ) -> Mapping[str, float]:
-    """For each sub-graph induced over the edges matching the annotation, calculate the average score
-    for all of the contained biological processes
+    """Calculate the average score for all biological processes for each subgraph.
 
-    Assumes you haven't done anything yet
+    Subgraphs are induced over edges matching the annotation.
+
+    Assumes you haven't done anything yet,
 
     1. Generates biological process upstream candidate mechanistic sub-graphs with
        :func:`generate_bioprocess_mechanisms`
