@@ -12,6 +12,8 @@ import logging
 from collections import Counter
 from typing import List, Mapping, Optional
 
+from tqdm import tqdm
+
 from pybel import BELGraph, Pipeline
 from pybel.constants import GENE
 from pybel.dsl import BaseEntity, Gene
@@ -36,15 +38,18 @@ neurommsig_graph_preprocessor = Pipeline.from_functions([
 ])
 
 
-def get_neurommsig_scores(graph: BELGraph,
-                          genes: List[Gene],
-                          annotation: str = 'Subgraph',
-                          ora_weight: Optional[float] = None,
-                          hub_weight: Optional[float] = None,
-                          top_percent: Optional[float] = None,
-                          topology_weight: Optional[float] = None,
-                          preprocess: bool = False
-                          ) -> Optional[Mapping[str, float]]:
+def get_neurommsig_scores(
+    graph: BELGraph,
+    genes: List[Gene],
+    annotation: str = 'Subgraph',
+    ora_weight: Optional[float] = None,
+    hub_weight: Optional[float] = None,
+    top_percent: Optional[float] = None,
+    topology_weight: Optional[float] = None,
+    preprocess: bool = False,
+    use_tqdm: bool = False,
+    tqdm_kwargs: Optional[Mapping] = None,
+) -> Optional[Mapping[str, float]]:
     """Preprocess the graph, stratify by the given annotation, then run the NeuroMMSig algorithm on each.
 
     :param graph: A BEL graph
@@ -69,8 +74,11 @@ def get_neurommsig_scores(graph: BELGraph,
     if preprocess:
         graph = neurommsig_graph_preprocessor.run(graph)
 
-    if not any(gene in graph for gene in genes):
-        logger.debug('no genes mapping to graph')
+    if all(isinstance(gene, str) for gene in genes):
+        genes = [Gene('HGNC', gene) for gene in genes]
+
+    if all(gene not in graph for gene in genes):
+        logger.warning('no genes mapping to graph')
         return
 
     subgraphs = get_subgraphs_by_annotation(graph, annotation=annotation)
@@ -82,17 +90,22 @@ def get_neurommsig_scores(graph: BELGraph,
         hub_weight=hub_weight,
         top_percent=top_percent,
         topology_weight=topology_weight,
+        use_tqdm=use_tqdm,
+        tqdm_kwargs=tqdm_kwargs,
     )
 
 
-def get_neurommsig_scores_prestratified(subgraphs: Mapping[str, BELGraph],
-                                        genes: List[Gene],
-                                        ora_weight: Optional[float] = None,
-                                        hub_weight: Optional[float] = None,
-                                        top_percent: Optional[float] = None,
-                                        topology_weight: Optional[float] = None,
-                                        ) -> Optional[Mapping[str, float]]:
-    """Takes a graph stratification and runs neurommsig on each
+def get_neurommsig_scores_prestratified(
+    subgraphs: Mapping[str, BELGraph],
+    genes: List[Gene],
+    ora_weight: Optional[float] = None,
+    hub_weight: Optional[float] = None,
+    top_percent: Optional[float] = None,
+    topology_weight: Optional[float] = None,
+    use_tqdm: bool = False,
+    tqdm_kwargs: Optional[Mapping] = None,
+) -> Mapping[str, float]:
+    """Run NeuroMMSig on a graph strata.
 
     :param subgraphs: A pre-stratified set of graphs
     :param genes: A list of gene nodes
@@ -103,6 +116,7 @@ def get_neurommsig_scores_prestratified(subgraphs: Mapping[str, BELGraph],
     :param top_percent: The percentage of top genes to use as hubs. Defaults to 5% (0.05).
     :param topology_weight: The relative weight of the topolgical analysis core from
      :py:func:`neurommsig_topology`. Defaults to 1.0.
+    :param use_tqdm: If true, show a progress bar
     :return: A dictionary from {annotation value: NeuroMMSig composite score}
 
     Pre-processing steps:
@@ -111,6 +125,9 @@ def get_neurommsig_scores_prestratified(subgraphs: Mapping[str, BELGraph],
     2. Collapse all proteins, RNAs and miRNAs to genes with :func:``
     3. Collapse variants to genes with :func:``
     """
+    it = subgraphs.items()
+    if use_tqdm:
+        it = tqdm(it, **(tqdm_kwargs or {}))
     return {
         name: get_neurommsig_score(
             graph=subgraph,
@@ -120,16 +137,18 @@ def get_neurommsig_scores_prestratified(subgraphs: Mapping[str, BELGraph],
             top_percent=top_percent,
             topology_weight=topology_weight,
         )
-        for name, subgraph in subgraphs.items()
+        for name, subgraph in it
     }
 
 
-def get_neurommsig_score(graph: BELGraph,
-                         genes: List[Gene],
-                         ora_weight: Optional[float] = None,
-                         hub_weight: Optional[float] = None,
-                         top_percent: Optional[float] = None,
-                         topology_weight: Optional[float] = None) -> float:
+def get_neurommsig_score(
+    graph: BELGraph,
+    genes: List[Gene],
+    ora_weight: Optional[float] = None,
+    hub_weight: Optional[float] = None,
+    top_percent: Optional[float] = None,
+    topology_weight: Optional[float] = None,
+) -> float:
     """Calculate the composite NeuroMMSig Score for a given list of genes.
 
     :param graph: A BEL graph
@@ -155,9 +174,9 @@ def get_neurommsig_score(graph: BELGraph,
     topology_score = neurommsig_topology(graph, genes)
 
     weighted_sum = (
-            ora_weight * ora_score +
-            hub_weight * hub_score +
-            topology_weight * topology_score
+        ora_weight * ora_score +
+        hub_weight * hub_score +
+        topology_weight * topology_score
     )
 
     return weighted_sum / total_weight
@@ -165,8 +184,8 @@ def get_neurommsig_score(graph: BELGraph,
 
 def neurommsig_gene_ora(graph: BELGraph, genes: List[Gene]) -> float:
     """Calculate the percentage of target genes mappable to the graph.
-    
-    Assume: graph central dogma inferred, collapsed to genes, collapsed variants 
+
+    Assume: graph central dogma inferred, collapsed to genes, collapsed variants
     """
     graph_genes = set(get_nodes_by_function(graph, GENE))
     return len(graph_genes.intersection(genes)) / len(graph_genes)
@@ -174,9 +193,9 @@ def neurommsig_gene_ora(graph: BELGraph, genes: List[Gene]) -> float:
 
 def neurommsig_hubs(graph: BELGraph, genes: List[Gene], top_percent: Optional[float] = None) -> float:
     """Calculate the percentage of target genes mappable to the graph.
-    
+
     Assume: graph central dogma inferred, collapsed to genes, collapsed variants, graph has more than 20 nodes
-    
+
     :param graph: A BEL graph
     :param genes: A list of nodes
     :param top_percent: The percentage of top genes to use as hubs. Defaults to 5% (0.05).
@@ -210,12 +229,10 @@ def neurommsig_hubs(graph: BELGraph, genes: List[Gene], top_percent: Optional[fl
 
 
 def neurommsig_topology(graph: BELGraph, nodes: List[BaseEntity]) -> float:
-    """Calculate the node neighbor score for a given list of nodes.
-    
-    -  Doesn't consider self loops
+    r"""Calculate the node neighbor score for a given list of nodes without considering self-loops.
 
     .. math::
-        
+
          \frac{\sum_i^n N_G[i]}{n*(n-1)}
     """
     nodes = list(nodes)
