@@ -3,11 +3,11 @@
 """This module contains functions that provide summaries of the errors encountered while parsing a BEL script."""
 
 from collections import Iterable, defaultdict
-from typing import List, Mapping, Optional, Set
+from typing import Counter, List, Mapping, Optional, Set, Tuple
 
 from pybel import BELGraph
 from pybel.constants import ANNOTATIONS
-from pybel.parser.exc import (
+from pybel.exceptions import (
     MissingNamespaceNameWarning, MissingNamespaceRegexWarning, UndefinedAnnotationWarning, UndefinedNamespaceWarning,
 )
 from pybel.struct.filters.edge_predicates import edge_has_annotation
@@ -89,7 +89,7 @@ def get_incorrect_names(graph: BELGraph) -> Mapping[str, Set[str]]:
 
 def get_undefined_annotations(graph: BELGraph) -> Set[str]:
     """Get all annotations that aren't actually defined.
-    
+
     :return: The set of all undefined annotations
     """
     return {
@@ -149,13 +149,20 @@ def group_errors(graph: BELGraph) -> Mapping[str, List[int]]:
     return dict(warning_summary)
 
 
-def get_most_common_errors(graph: BELGraph, n: Optional[int] = 20):
+def count_errors(graph: BELGraph) -> Counter[str]:
+    """Count the errors in the graph."""
+    return count_dict_values(group_errors(graph))
+
+
+def get_most_common_errors(graph: BELGraph, n: Optional[int] = 20) -> List[Tuple[str, int]]:
     """Get the (n) most common errors in a graph."""
-    return count_dict_values(group_errors(graph)).most_common(n)
+    return count_errors(graph).most_common(n)
 
 
 def get_names_including_errors_by_namespace(graph: BELGraph, namespace: str) -> Set[str]:
-    """Takes the names from the graph in a given namespace (:func:`pybel.struct.summary.get_names_by_namespace`) and
+    """Get all names appearing in the graph, including erroneous names, for the given namespace.
+
+    Takes the names from the graph in a given namespace (:func:`pybel.struct.summary.get_names_by_namespace`) and
     the erroneous names from the same namespace (:func:`get_incorrect_names_by_namespace`) and returns them together
     as a unioned set
 
@@ -165,7 +172,9 @@ def get_names_including_errors_by_namespace(graph: BELGraph, namespace: str) ->
 
 
 def get_names_including_errors(graph: BELGraph) -> Mapping[str, Set[str]]:
-    """Takes the names from the graph in a given namespace and the erroneous names from the same namespace and returns
+    """Get all names appearing in the graph, including erroneous names, and group in a dictionary by namespace.
+
+    Takes the names from the graph in a given namespace and the erroneous names from the same namespace and returns
     them together as a unioned set
 
     :return: The dict of the sets of all correct and incorrect names from the given namespace in the graph
