@@ -1,19 +1,18 @@
 # -*- coding: utf-8 -*-
 
-"""This module contains functions that calculate properties of nodes"""
+"""This module contains functions that calculate properties of nodes."""
 
-from collections import Counter
-from typing import Any, Iterable, Mapping, Optional, Set, Tuple, Union
+from collections import Counter, defaultdict
+from typing import Iterable, List, Mapping, Optional, Set, Tuple, Union
 
 import networkx as nx
 
 from pybel import BELGraph
+from pybel.constants import CITATION
 from pybel.dsl import BaseEntity
-from pybel.struct.filters import get_nodes
 from pybel.struct.filters.edge_predicates import is_causal_relation
-from pybel.struct.filters.node_predicates import (
-    has_activity, is_causal_central, is_causal_sink, is_causal_source, is_degraded, is_translocated,
-)
+from pybel.struct.filters.node_predicates import is_causal_central, is_causal_sink, is_causal_source
+from pybel.struct.summary.node_summary import count_modifications, get_activities, get_degradations, get_translocated
 
 __all__ = [
     'is_causal_relation',
@@ -30,13 +29,14 @@ __all__ = [
     'get_translocated',
     'count_top_centrality',
     'count_top_degrees',
-    'get_modifications_count',
+    'count_modifications',
+    'get_node_citations',
 ]
 
 
 def get_causal_out_edges(
-        graph: BELGraph,
-        nbunch: Union[BaseEntity, Iterable[BaseEntity]],
+    graph: BELGraph,
+    nbunch: Union[BaseEntity, Iterable[BaseEntity]],
 ) -> Set[Tuple[BaseEntity, BaseEntity]]:
     """Get the out-edges to the given node that are causal.
 
@@ -50,8 +50,8 @@ def get_causal_out_edges(
 
 
 def get_causal_in_edges(
-        graph: BELGraph,
-        nbunch: Union[BaseEntity, Iterable[BaseEntity]],
+    graph: BELGraph,
+    nbunch: Union[BaseEntity, Iterable[BaseEntity]],
 ) -> Set[Tuple[BaseEntity, BaseEntity]]:
     """Get the in-edges to the given node that are causal.
 
@@ -90,7 +90,7 @@ def get_causal_central_nodes(graph: BELGraph, func: str) -> Set[BaseEntity]:
 
 
 def get_causal_sink_nodes(graph: BELGraph, func) -> Set[BaseEntity]:
-    """Returns a set of all ABUNDANCE nodes that have an causal out-degree of 0.
+    """Return a set of all ABUNDANCE nodes that have an causal out-degree of 0.
 
     This likely means that the knowledge assembly is incomplete, or there is a curation error.
     """
@@ -101,22 +101,8 @@ def get_causal_sink_nodes(graph: BELGraph, func) -> Set[BaseEntity]:
     }
 
 
-def get_degradations(graph: BELGraph) -> Set[BaseEntity]:
-    """Get all nodes that are degraded."""
-    return get_nodes(graph, is_degraded)
-
-
-def get_activities(graph: BELGraph) -> Set[BaseEntity]:
-    """Get all nodes that have molecular activities."""
-    return get_nodes(graph, has_activity)
-
-
-def get_translocated(graph: BELGraph) -> Set[BaseEntity]:
-    """Get all nodes that are translocated."""
-    return get_nodes(graph, is_translocated)
-
-
-def count_top_degrees(graph: BELGraph, number: Optional[int] = 30):
+def count_top_degrees(graph: BELGraph, number: Optional[int] = 30) -> Mapping[BaseEntity, int]:
+    """Get the nodes with the top degrees."""
     dd = graph.degree()
     dc = Counter(dd)
     return dict(dc.most_common(number))
@@ -129,19 +115,18 @@ def count_top_centrality(graph: BELGraph, number: Optional[int] = 30) -> Mapping
     return dict(dc.most_common(number))
 
 
-def get_modifications_count(graph: BELGraph) -> Mapping[str, int]:
-    """Get a modifications count dictionary."""
-    return remove_falsy_values({
-        'Translocations': len(get_translocated(graph)),
-        'Degradations': len(get_degradations(graph)),
-        'Molecular Activities': len(get_activities(graph)),
-    })
+def get_node_citations(graph: BELGraph, node: BaseEntity) -> Mapping[BaseEntity, List[Mapping]]:
+    """Get a mapping from all nodes incident to the given node to their shared edges' citations."""
+    rv = defaultdict(list)
+    for t, citation in _iter_node_citations(graph, node):
+        rv[t].append(citation)
+    return dict(rv)
 
 
-def remove_falsy_values(counter: Mapping[Any, int]) -> Mapping[Any, int]:
-    """Remove all values that are zero."""
-    return {
-        label: count
-        for label, count in counter.items()
-        if count
-    }
+def _iter_node_citations(graph: BELGraph, node: BaseEntity):
+    for u, _, data in graph.in_edges(node, data=True):
+        if CITATION in data:
+            yield u, data[CITATION]
+    for _, v, data in graph.out_edges(node, data=True):
+        if CITATION in data:
+            yield v, data[CITATION]
