@@ -10,15 +10,13 @@ from datetime import datetime
 from typing import Iterable, List, Mapping, Optional, Set, Tuple, Union
 
 from pybel import BELGraph
-from pybel.constants import (
-    ANNOTATIONS, CITATION, CITATION_AUTHORS, CITATION_DATE, CITATION_REFERENCE, CITATION_TYPE, EVIDENCE,
-)
+from pybel.constants import ANNOTATIONS, CITATION, CITATION_AUTHORS, CITATION_DATE, EVIDENCE
 from pybel.dsl import BaseEntity
-from pybel.struct.filters import filter_edges
-from pybel.struct.filters.edge_predicates import edge_has_annotation
+from pybel.struct import build_pmid_inclusion_filter, edge_has_annotation, filter_edges
 from pybel.struct.summary import iterate_pubmed_identifiers
-from ..filters import build_edge_data_filter, build_pmid_inclusion_filter
-from ..utils import count_defaultdict, count_dict_values, group_as_dict
+from pybel.typing import Strings
+from ..filters import build_edge_data_filter
+from ..utils import count_defaultdict, count_dict_values, group_as_lists, group_as_sets
 
 __all__ = [
     'count_pmids',
@@ -27,7 +25,6 @@ __all__ = [
     'count_citations_by_annotation',
     'count_authors',
     'count_author_publications',
-    'get_authors',
     'get_authors_by_keyword',
     'count_authors_by_annotation',
     'get_evidences_by_pmid',
@@ -37,7 +34,7 @@ __all__ = [
     'count_confidences',
 ]
 
-log = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 
 def _generate_citation_dict(graph: BELGraph) -> Mapping[str, Mapping[Tuple[BaseEntity, BaseEntity], str]]:
@@ -50,17 +47,18 @@ def _generate_citation_dict(graph: BELGraph) -> Mapping[str, Mapping[Tuple[BaseE
     for u, v, data in graph.edges(data=True):
         if CITATION not in data:
             continue
-        results[data[CITATION][CITATION_TYPE]][u, v].add(data[CITATION][CITATION_REFERENCE].strip())
+        results[data[CITATION].namespace][u, v].add(data[CITATION].identifier.strip())
 
     return dict(results)
 
 
-def get_pmid_by_keyword(keyword: str,
-                        graph: Optional[BELGraph] = None,
-                        pubmed_identifiers: Optional[Set[str]] = None,
-                        ) -> Set[str]:
+def get_pmid_by_keyword(
+    keyword: str,
+    graph: Optional[BELGraph] = None,
+    pubmed_identifiers: Optional[Set[str]] = None,
+) -> Set[str]:
     """Get the set of PubMed identifiers beginning with the given keyword string.
-    
+
     :param keyword: The beginning of a PubMed identifier
     :param graph: A BEL graph
     :param pubmed_identifiers: A set of pre-cached PubMed identifiers
@@ -92,21 +90,18 @@ def count_pmids(graph: BELGraph) -> Counter:
 
 
 def count_citations(graph: BELGraph, **annotations) -> Counter:
-    """Counts the citations in a graph based on a given filter
+    """Count the citations in a graph based on a given filter.
 
     :param graph: A BEL graph
     :param dict annotations: The annotation filters to use
     :return: A counter from {(citation type, citation reference): frequency}
     """
-    citations = defaultdict(set)
-
     annotation_dict_filter = build_edge_data_filter(annotations)
 
+    citations = defaultdict(set)
     for u, v, _, d in filter_edges(graph, annotation_dict_filter):
-        if CITATION not in d:
-            continue
-
-        citations[u, v].add((d[CITATION][CITATION_TYPE], d[CITATION][CITATION_REFERENCE].strip()))
+        if CITATION in d:
+            citations[u, v].add((d[CITATION].namespace, d[CITATION].identifier))
 
     return Counter(itt.chain.from_iterable(citations.values()))
 
@@ -125,19 +120,22 @@ def count_citations_by_annotation(graph: BELGraph, annotation: str) -> Mapping[s
 
         k = data[ANNOTATIONS][annotation]
 
-        citations[k][u, v].add((data[CITATION][CITATION_TYPE], data[CITATION][CITATION_REFERENCE].strip()))
+        citations[k][u, v].add((data[CITATION].namespace, data[CITATION].identifier))
 
-    return {k: Counter(itt.chain.from_iterable(v.values())) for k, v in citations.items()}
+    return {
+        k: Counter(itt.chain.from_iterable(v.values()))
+        for k, v in citations.items()
+    }
 
 
 def count_authors(graph: BELGraph) -> typing.Counter[str]:
     """Count the number of edges in which each author appears."""
-    return Counter(graph._iterate_authors())
+    return graph.count.authors()
 
 
 def count_author_publications(graph: BELGraph) -> typing.Counter[str]:
     """Count the number of publications of each author to the given graph."""
-    authors = group_as_dict(_iter_author_publiations(graph))
+    authors = group_as_lists(_iter_author_publiations(graph))
     return Counter(count_dict_values(count_defaultdict(authors)))
 
 
@@ -148,7 +146,7 @@ def _iter_author_publiations(graph: BELGraph) -> Iterable[Tuple[str, Tuple[str,
         for author in data[CITATION][CITATION_AUTHORS]:
             yield (
                 author,
-                (data[CITATION][CITATION_TYPE], data[CITATION][CITATION_REFERENCE])
+                (data[CITATION].namespace, data[CITATION].identifier)
             )
 
 
@@ -159,7 +157,7 @@ def get_authors(graph: BELGraph) -> Set[str]:
 
 def get_authors_by_keyword(keyword: str, graph=None, authors=None) -> Set[str]:
     """Get authors for whom the search term is a substring.
-    
+
     :param pybel.BELGraph graph: A BEL graph
     :param keyword: The keyword to search the author strings for
     :param set[str] authors: An optional set of pre-cached authors calculated from the graph
@@ -179,7 +177,7 @@ def get_authors_by_keyword(keyword: str, graph=None, authors=None) -> Set[str]:
 
     return {
         author
-        for author in get_authors(graph)
+        for author in graph.get_authors()
         if keyword_lower in author.lower()
     }
 
@@ -191,7 +189,7 @@ def count_authors_by_annotation(graph: BELGraph, annotation: str = 'Subgraph') -
     :param annotation: The annotation to use to group the graph
     :return: A dictionary of Counters {subgraph name: Counter from {author: frequency}}
     """
-    authors = group_as_dict(_iter_authors_by_annotation(graph, annotation=annotation))
+    authors = group_as_lists(_iter_authors_by_annotation(graph, annotation=annotation))
     return count_defaultdict(authors)
 
 
@@ -203,21 +201,17 @@ def _iter_authors_by_annotation(graph: BELGraph, annotation: str = 'Subgraph') -
             yield data[ANNOTATIONS][annotation], author
 
 
-def get_evidences_by_pmid(graph: BELGraph, pmids: Union[str, Iterable[str]]):
-    """Get a dictionary from the given PubMed identifiers to the sets of all evidence strings associated with each
-    in the graph.
+def get_evidences_by_pmid(graph: BELGraph, pmids: Strings) -> Mapping[str, Set[str]]:
+    """Map PubMed identifiers to their evidence strings appearing in the graph.
 
     :param graph: A BEL graph
     :param pmids: An iterable of PubMed identifiers, as strings. Is consumed and converted to a set.
     :return: A dictionary of {pmid: set of all evidence strings}
-    :rtype: dict
     """
-    result = defaultdict(set)
-
-    for _, _, _, data in filter_edges(graph, build_pmid_inclusion_filter(pmids)):
-        result[data[CITATION][CITATION_REFERENCE]].add(data[EVIDENCE])
-
-    return dict(result)
+    return group_as_sets(
+        (data[CITATION].identifier, data[EVIDENCE])
+        for _, _, _, data in filter_edges(graph, build_pmid_inclusion_filter(pmids))
+    )
 
 
 # TODO date parsing should be handled during either pybel parse-time or during graph loading.
@@ -231,14 +225,18 @@ def count_citation_years(graph: BELGraph) -> typing.Counter[int]:
 
         try:
             dt = _ensure_datetime(data[CITATION][CITATION_DATE])
-            result[dt.year].add((data[CITATION][CITATION_TYPE], data[CITATION][CITATION_REFERENCE]))
-        except Exception:
+        except ValueError:
             continue
+        else:
+            result[dt.year].add((
+                data[CITATION].namespace,
+                data[CITATION].identifier,
+            ))
 
     return count_dict_values(result)
 
 
-def _ensure_datetime(s):
+def _ensure_datetime(s: Union[datetime, str]) -> datetime:
     if isinstance(s, datetime):
         return s
 
