@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-"""This module contains functions useful throughout PyBEL Tools"""
+"""This module contains functions useful throughout PyBEL Tools."""
 
 import datetime
 import itertools as itt
@@ -14,27 +14,28 @@ from typing import Callable, Dict, Iterable, List, Mapping, Optional, Set, Sized
 import networkx as nx
 
 from pybel import BELGraph
-from .constants import VERSION
 
-log = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 CENTRALITY_SAMPLES = 200
 X = TypeVar('X')
 Y = TypeVar('Y')
 
 
-def pairwise(iterable: Iterable[X]) -> Iterable[Tuple[X, X]]:
-    """Iterate over pairs in list s -> (s0,s1), (s1,s2), (s2, s3), ..."""
-    a, b = itt.tee(iterable)
-    next(b, None)
-    return zip(a, b)
+def group_as_sets(pairs: Iterable[Tuple[X, Y]]) -> Mapping[X, Set[Y]]:
+    """Group elements in the iterable in a dictionary of sets."""
+    rv = defaultdict(set)
+    for x, y in pairs:
+        rv[x].add(y)
+    return dict(rv)
 
 
-def group_as_dict(list_of_pairs: Iterable[Tuple[X, Y]]) -> Mapping[X, List[Y]]:
-    r = defaultdict(list)
-    for a, b in list_of_pairs:
-        r[a].append(b)
-    return dict(r)
+def group_as_lists(pairs: Iterable[Tuple[X, Y]]) -> Mapping[X, List[Y]]:
+    """Group elements in the iterable in a dictionary of lists."""
+    rv = defaultdict(list)
+    for x, y in pairs:
+        rv[x].append(y)
+    return dict(rv)
 
 
 def count_defaultdict(dict_of_lists: Mapping[X, List[Y]]) -> Mapping[X, typing.Counter[Y]]:
@@ -58,10 +59,10 @@ def count_dict_values(dict_of_counters: Mapping[X, Sized]) -> typing.Counter[X]:
 
 
 def set_percentage(x: Iterable[X], y: Iterable[X]) -> float:
-    """What percentage of x is contained within y?
+    """Return what percentage of x is contained within y.
 
-    :param set x: A set
-    :param set y: Another set
+    :param x: A set
+    :param y: Another set
     :return: The percentage of x contained within y
     """
     a, b = set(x), set(y)
@@ -86,10 +87,10 @@ def tanimoto_set_similarity(x: Iterable[X], y: Iterable[X]) -> float:
 def min_tanimoto_set_similarity(x: Iterable[X], y: Iterable[X]) -> float:
     """Calculate the tanimoto set similarity using the minimum size.
 
-    :param set x: A set
-    :param set y: Another set
+    :param x: A set
+    :param y: Another set
     :return: The similarity between
-        """
+    """
     a, b = set(x), set(y)
 
     if not a or not b:
@@ -98,17 +99,18 @@ def min_tanimoto_set_similarity(x: Iterable[X], y: Iterable[X]) -> float:
     return len(a & b) / min(len(a), len(b))
 
 
-def calculate_single_tanimoto_set_distances(target: Iterable[X], dict_of_sets: Mapping[Y, Set[X]]) -> Mapping[Y, float]:
+def calculate_single_tanimoto_set_distances(
+    target: Iterable[X],
+    dict_of_sets: Mapping[Y, Set[X]],
+) -> Mapping[Y, float]:
     """Return a dictionary of distances keyed by the keys in the given dict.
 
     Distances are calculated based on pairwise tanimoto similarity of the sets contained
 
-    :param set target: A set
+    :param target: A set
     :param dict_of_sets: A dict of {x: set of y}
-    :type dict_of_sets: dict
-    :return: A similarity dicationary based on the set overlap (tanimoto) score between the target set and the sets in
+    :return: A similarity dictionary based on the set overlap (tanimoto) score between the target set and the sets in
             dos
-    :rtype: dict
     """
     target_set = set(target)
 
@@ -118,7 +120,9 @@ def calculate_single_tanimoto_set_distances(target: Iterable[X], dict_of_sets: M
     }
 
 
-def calculate_tanimoto_set_distances(dict_of_sets: Mapping[X, Set]) -> Mapping[X, Mapping[X, float]]:
+def calculate_tanimoto_set_distances(
+    dict_of_sets: Mapping[X, Set],
+) -> Mapping[X, Mapping[X, float]]:
     """Return a distance matrix keyed by the keys in the given dict.
 
     Distances are calculated based on pairwise tanimoto similarity of the sets contained.
@@ -160,7 +164,7 @@ def calculate_global_tanimoto_set_distances(dict_of_sets: Mapping[X, Set]) -> Ma
 
 
 def barh(d, plt, title=None):
-    """A convenience function for plotting a horizontal bar plot from a Counter"""
+    """Plot a horizontal bar plot from a Counter."""
     labels = sorted(d, key=d.get)
     index = range(len(labels))
 
@@ -172,7 +176,7 @@ def barh(d, plt, title=None):
 
 
 def barv(d, plt, title=None, rotation='vertical'):
-    """A convenience function for plotting a vertical bar plot from a Counter"""
+    """Plot a vertical bar plot from a Counter."""
     labels = sorted(d, key=d.get, reverse=True)
     index = range(len(labels))
     plt.xticks(index, labels, rotation=rotation)
@@ -182,56 +186,65 @@ def barv(d, plt, title=None, rotation='vertical'):
         plt.title(title)
 
 
-def safe_add_edge(graph, u, v, key, attr_dict, **attr):
-    """Adds an edge while preserving negative keys, and paying no respect to positive ones
-
-    :param pybel.BELGraph graph: A BEL Graph
-    :param tuple u: The source BEL node
-    :param tuple v: The target BEL node
-    :param int key: The edge key. If less than zero, corresponds to an unqualified edge, else is disregarded
-    :param dict attr_dict: The edge data dictionary
-    :param dict attr: Edge data to assign via keyword arguments
-    """
-    if key < 0:
-        graph.add_edge(u, v, key=key, attr_dict=attr_dict, **attr)
-    else:
-        graph.add_edge(u, v, attr_dict=attr_dict, **attr)
-
-
-def prepare_c3(data: Union[List[Tuple[str, int]], Mapping[str, int]],
-               y_axis_label: str = 'y',
-               x_axis_label: str = 'x',
-               ) -> str:
-    """Prepares C3 JSON for making a bar chart from a Counter
+def prepare_c3(
+    data: Union[List[Tuple[str, int]], Mapping[str, int]],
+    y_axis_label: Optional[str] = None,
+    x_axis_label: Optional[str] = None,
+) -> str:
+    """Prepare a C3 JSON for making a bar chart from a Counter.
 
     :param data: A dictionary of {str: int} to display as bar chart
     :param y_axis_label: The Y axis label
     :param x_axis_label: X axis internal label. Should be left as default 'x')
     :return: A JSON dictionary for making a C3 bar chart
     """
+    return json.dumps(prepare_c3_json(data=data, y_axis_label=y_axis_label, x_axis_label=x_axis_label))
+
+
+def prepare_c3_json(
+    data: Union[List[Tuple[str, int]], Mapping[str, int]],
+    y_axis_label: Optional[str] = None,
+    x_axis_label: Optional[str] = None,
+) -> List:
+    """Prepare a C3 JSON for making a bar chart from a Counter.
+
+    :param data: A dictionary of {str: int} to display as bar chart
+    :param y_axis_label: The Y axis label
+    :param x_axis_label: X axis internal label. Should be left as default 'x')
+    :return: A JSON dictionary for making a C3 bar chart
+    """
+    if y_axis_label is None:
+        y_axis_label = 'y'
+
+    if x_axis_label is None:
+        x_axis_label = 'x'
+
     if not isinstance(data, list):
         data = sorted(data.items(), key=itemgetter(1), reverse=True)
 
     try:
         labels, values = zip(*data)
     except ValueError:
-        log.info(f'no values found for {x_axis_label}, {y_axis_label}')
+        logger.debug(f'no values found for {x_axis_label}, {y_axis_label}')
         labels, values = [], []
 
-    return json.dumps([
+    return [
         [x_axis_label] + list(labels),
         [y_axis_label] + list(values),
-    ])
+    ]
 
 
 def prepare_c3_time_series(data: List[Tuple[int, int]], y_axis_label: str = 'y', x_axis_label: str = 'x') -> str:
-    """Prepare C3 JSON string dump for a time series.
+    """Prepare a C3 JSON string dump for a time series.
 
     :param data: A list of tuples [(year, count)]
     :param y_axis_label: The Y axis label
     :param x_axis_label: X axis internal label. Should be left as default 'x')
     """
-    years, counter = zip(*data)
+    try:
+        years, counter = zip(*data)
+    except ValueError:
+        years, counter = [], []
 
     years = [
         datetime.date(year, 1, 1).isoformat()
@@ -244,12 +257,6 @@ def prepare_c3_time_series(data: List[Tuple[int, int]], y_axis_label: str = 'y',
     ])
 
 
-def enable_cool_mode() -> None:
-    log.info('enabled cool mode')
-    logging.getLogger('urllib3.connectionpool').setLevel(logging.ERROR)
-    logging.getLogger('pybel.parser').setLevel(logging.CRITICAL)
-
-
 def calculate_betweenness_centality(graph: BELGraph, number_samples: int = CENTRALITY_SAMPLES) -> Counter:
     """Calculate the betweenness centrality over nodes in the graph.
 
@@ -269,21 +276,17 @@ def get_circulations(elements: T) -> Iterable[T]:
     """Iterate over all possible circulations of an ordered collection (tuple or list).
 
     Example:
-
     >>> list(get_circulations([1, 2, 3]))
     [[1, 2, 3], [2, 3, 1], [3, 1, 2]]
+
     """
     for i in range(len(elements)):
         yield elements[i:] + elements[:i]
 
 
 def canonical_circulation(elements: T, key: Optional[Callable[[T], bool]] = None) -> T:
-    """Get get a canonical representation of the ordered collection by finding its minimum circulation with the
-    given sort key
+    """Get the canonical representation of the ordered collection.
+
+    Does this by finding its minimum circulation with the given sort key
     """
     return min(get_circulations(elements), key=key)
-
-
-def get_version() -> str:
-    """Get the current PyBEL Tools version."""
-    return VERSION
