@@ -1,25 +1,28 @@
 import unittest
 
 from pybel import BELGraph
-from pybel.constants import *
-from pybel.dsl import protein
-from pybel_tools.analysis.stability import *
+from pybel.constants import DECREASES, INCREASES, NEGATIVE_CORRELATION, POSITIVE_CORRELATION, RELATION
+from pybel.dsl import Protein
 from pybel_tools.mutation.inference import infer_missing_two_way_edges
+from pybel_tools.summary import (
+    get_correlation_graph, get_correlation_triangles, get_mutually_unstable_correlation_triples,
+    get_separate_unstable_correlation_triples,
+)
 
 
 class TestUnstableTriplets(unittest.TestCase):
     def test_separate_unstable(self):
         graph = BELGraph()
 
-        a_data = protein('HGNC', 'A')
-        b_data = protein('HGNC', 'B')
-        c_data = protein('HGNC', 'C')
-        d_data = protein('HGNC', 'D')
+        a = Protein('HGNC', 'A')
+        b = Protein('HGNC', 'B')
+        c = Protein('HGNC', 'C')
+        d = Protein('HGNC', 'D')
 
-        a = graph.add_node_from_data(a_data)
-        b = graph.add_node_from_data(b_data)
-        c = graph.add_node_from_data(c_data)
-        d = graph.add_node_from_data(d_data)
+        graph.add_node_from_data(a)
+        graph.add_node_from_data(b)
+        graph.add_node_from_data(c)
+        graph.add_node_from_data(d)
 
         graph.add_edge(a, b, **{RELATION: POSITIVE_CORRELATION})
         graph.add_edge(a, c, **{RELATION: POSITIVE_CORRELATION})
@@ -51,15 +54,15 @@ class TestUnstableTriplets(unittest.TestCase):
     def test_mutually_unstable(self):
         graph = BELGraph()
 
-        a_data = protein('HGNC', 'A')
-        b_data = protein('HGNC', 'B')
-        c_data = protein('HGNC', 'C')
-        d_data = protein('HGNC', 'D')
+        a = Protein('HGNC', 'A')
+        b = Protein('HGNC', 'B')
+        c = Protein('HGNC', 'C')
+        d = Protein('HGNC', 'D')
 
-        a = graph.add_node_from_data(a_data)
-        b = graph.add_node_from_data(b_data)
-        c = graph.add_node_from_data(c_data)
-        d = graph.add_node_from_data(d_data)
+        graph.add_node_from_data(a)
+        graph.add_node_from_data(b)
+        graph.add_node_from_data(c)
+        graph.add_node_from_data(d)
 
         graph.add_edge(a, b, **{RELATION: NEGATIVE_CORRELATION})
         graph.add_edge(a, c, **{RELATION: NEGATIVE_CORRELATION})
@@ -76,17 +79,17 @@ class TestUnstableTriplets(unittest.TestCase):
     def test_jens_alpha(self):
         graph = BELGraph()
 
-        a_data = protein('HGNC', 'A')
-        b_data = protein('HGNC', 'B')
-        c_data = protein('HGNC', 'C')
-        d_data = protein('HGNC', 'D')
-        e_data = protein('HGNC', 'e')
+        a = Protein('HGNC', 'A')
+        b = Protein('HGNC', 'B')
+        c = Protein('HGNC', 'C')
+        d = Protein('HGNC', 'D')
+        e = Protein('HGNC', 'e')
 
-        a = graph.add_node_from_data(a_data)
-        b = graph.add_node_from_data(b_data)
-        c = graph.add_node_from_data(c_data)
-        d = graph.add_node_from_data(d_data)
-        e = graph.add_node_from_data(e_data)
+        graph.add_node_from_data(a)
+        graph.add_node_from_data(b)
+        graph.add_node_from_data(c)
+        graph.add_node_from_data(d)
+        graph.add_node_from_data(e)
 
         graph.add_edge(a, b, **{RELATION: INCREASES})
         graph.add_edge(a, c, **{RELATION: DECREASES})
